# Plugwise Smile python module

[![Build Status](https://travis-ci.org/plugwise/Plugwise-Smile.svg?branch=master)](https://travis-ci.org/plugwise/Plugwise-Smile)
[![codecov](https://codecov.io/gh/plugwise/Plugwise-Smile/branch/master/graph/badge.svg)](https://codecov.io/gh/plugwise/Plugwise-Smile)

Module providing interfacing with Plugwise:

  - [x] Anna
  - [ ] Legacy Anna (see haanna for now)
  - [x] Adam
  - [x]  - Floor
  - [ ]  - Koen
  - [x]  - Lisa
  - [x]  - Plug (each plug must have its own, unique, location-name, otherwise it will not show up) 
  - [x]  - Tom
  - [x] Smile (v3)
  - [ ]  - V2
  - [ ] [Home-Assistant](https://home-assistant.io) via 
  - [ ]  - Native -> 20200311 for now as 'plugwise' but using haanna
  - [x]  - `custom_component` [Plugwise-HA](https://github.com/plugwise/Plugwise-HA)
  - [ ]  - `HACS` [Plugwise-HA](https://github.com/plugwise/Plugwise-HA)

## License, origins and contributors

Original (and therefor, license) by [haanna](https://github.com/laetificat/haanna) by Kevin Heruer

Modified and adjusted by @CoMPaTech and @bouwew in his repository but in 2020 cloned to Plugwise to include more than 'just Anna'


# Thanks

On behalf of @CoMPaTech and @bouwew (as well as @riemers) we'd like to thank @TANE from [HAshop](https://hashop.nl) for his support and development devices

